==> dojo_1.11.0+dfsg.orig.tar.gz: dojo-release-1.11.0-src/dojo/cldr/nls/it/roc.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "questo sabato",
	"field-sat-relative+1": "sabato prossimo",
	"field-dayperiod": "periodo del giorno",
	"field-sun-relative+-1": "domenica scorsa",
	"field-mon-relative+-1": "lunedì scorso",
	"field-minute": "minuto",
	"field-day-relative+-1": "ieri",
	"field-weekday": "giorno della settimana",
	"field-day-relative+-2": "l'altro ieri",
	"field-era": "era",
	"field-hour": "ora",
	"field-sun-relative+0": "questa domenica",
	"field-sun-relative+1": "domenica prossima",
	"field-wed-relative+-1": "mercoledì scorso",
	"field-day-relative+0": "oggi",
	"field-day-relative+1": "domani",
	"eraAbbr": [
		"Prima della R.O.C.",
		"Minguo"
	],
	"field-day-relative+2": "dopodomani",
	"field-tue-relative+0": "questo martedì",
	"field-zone": "fuso orario",
	"field-tue-relative+1": "martedì prossimo",
	"field-week-relative+-1": "settimana scorsa",
	"field-year-relative+0": "quest'anno",
	"field-year-relative+1": "anno prossimo",
	"field-sat-relative+-1": "sabato scorso",
	"field-year-relative+-1": "anno scorso",
	"field-year": "anno",
	"field-fri-relative+0": "questo venerdì",
	"field-fri-relative+1": "venerdì prossimo",
	"field-week": "settimana",
	"field-week-relative+0": "questa settimana",
	"field-week-relative+1": "settimana prossima",
	"field-month-relative+0": "questo mese",
	"field-month": "mese",
	"field-month-relative+1": "mese prossimo",
	"field-fri-relative+-1": "venerdì scorso",
	"field-second": "secondo",
	"field-tue-relative+-1": "martedì scorso",
	"field-day": "giorno",
	"field-mon-relative+0": "questo lunedì",
	"field-mon-relative+1": "lunedì prossimo",
	"field-thu-relative+0": "questo giovedì",
	"field-second-relative+0": "ora",
	"field-thu-relative+1": "giovedì prossimo",
	"field-wed-relative+0": "questo mercoledì",
	"field-wed-relative+1": "mercoledì prossimo",
	"field-month-relative+-1": "mese scorso",
	"field-thu-relative+-1": "giovedì scorso"
}
//end v1.x content
);

==> dojo_1.13.0+dfsg1.orig.tar.gz: dojo-release-1.13.0-src/dojo/cldr/nls/it/roc.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "questo sabato",
	"field-sat-relative+1": "sabato prossimo",
	"field-dayperiod": "AM/PM",
	"field-sun-relative+-1": "domenica scorsa",
	"field-mon-relative+-1": "lunedì scorso",
	"field-minute": "Minuto",
	"field-day-relative+-1": "ieri",
	"field-weekday": "Giorno della settimana",
	"field-day-relative+-2": "l’altro ieri",
	"field-era": "Era",
	"field-hour": "Ora",
	"field-sun-relative+0": "questa domenica",
	"field-sun-relative+1": "domenica prossima",
	"field-wed-relative+-1": "mercoledì scorso",
	"field-day-relative+0": "oggi",
	"field-day-relative+1": "domani",
	"eraAbbr": [
		"Prima della R.O.C.",
		"Minguo"
	],
	"field-day-relative+2": "dopodomani",
	"field-tue-relative+0": "questo martedì",
	"field-zone": "Fuso orario",
	"field-tue-relative+1": "martedì prossimo",
	"field-week-relative+-1": "settimana scorsa",
	"field-year-relative+0": "quest’anno",
	"field-year-relative+1": "anno prossimo",
	"field-sat-relative+-1": "sabato scorso",
	"field-year-relative+-1": "anno scorso",
	"field-year": "Anno",
	"field-fri-relative+0": "questo venerdì",
	"field-fri-relative+1": "venerdì prossimo",
	"field-week": "Settimana",
	"field-week-relative+0": "questa settimana",
	"field-week-relative+1": "settimana prossima",
	"field-month-relative+0": "questo mese",
	"field-month": "Mese",
	"field-month-relative+1": "mese prossimo",
	"field-fri-relative+-1": "venerdì scorso",
	"field-second": "Secondo",
	"field-tue-relative+-1": "martedì scorso",
	"field-day": "Giorno",
	"field-mon-relative+0": "questo lunedì",
	"field-mon-relative+1": "lunedì prossimo",
	"field-thu-relative+0": "questo giovedì",
	"field-second-relative+0": "ora",
	"field-thu-relative+1": "giovedì prossimo",
	"field-wed-relative+0": "questo mercoledì",
	"field-wed-relative+1": "mercoledì prossimo",
	"field-month-relative+-1": "mese scorso",
	"field-thu-relative+-1": "giovedì scorso"
}
//end v1.x content
);
